@@ -1,6 +1,6 @@
 /* Convert struct partime into time_t.
 
-   Copyright (C) 2010-2014 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1992, 1993, 1994, 1995 Paul Eggert
 
    This file is part of GNU RCS.
@@ -29,10 +29,10 @@
 struct tm *
 local_tm (const time_t *timep, struct tm *result)
 {
-  if (! MAKETIMESTUFF (tzset_called_p))
+  if (! MAKETIMESTUFF (tzset_already_called))
     {
       tzset ();
-      MAKETIMESTUFF (tzset_called_p) = true;
+      MAKETIMESTUFF (tzset_already_called) = true;
     }
   return localtime_r (timep, result);
 }
@@ -275,7 +275,9 @@ tm2time (struct tm *tm, bool localzone, int yweek)
 
   /* Make a first guess.  */
   gt = MAKETIMESTUFF (t_cache)[localzone];
-  gtm = gt ? &MAKETIMESTUFF (tm_cache)[localzone] : time2tm (gt, localzone);
+  gtm = gt
+    ? &MAKETIMESTUFF (tm_cache)[localzone]
+    : time2tm (gt, localzone);
 
   /* Repeatedly use the error from the guess to improve the guess.  */
   while ((d = difftm (tm, gtm)) != 0)
