@@ -1,6 +1,6 @@
 /* Handle RCS revision numbers.
 
-   Copyright (C) 2010-2014 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -182,7 +182,9 @@ cmpnumfld (char const *num1, char const *num2, int fld)
   for (d2 = 0; isdigit (*(s2 + d2)); d2++)
     continue;
 
-  return d1 < d2 ? -1 : d1 == d2 ? memcmp (s1, s2, d1) : 1;
+  return d1 < d2 ? -1 : d1 == d2
+    ? memcmp (s1, s2, d1)
+    : 1;
 }
 
 static char const *
@@ -225,10 +227,10 @@ cmpdate (char const *d1, char const *d2)
 }
 
 static void
-cantfindbranch (char const *revno, char const date[datesize],
+cantfindbranch (char const *revno, char const date[DATESIZE],
                 char const *author, char const *state)
 {
-  char datebuf[datesize + zonelenmax];
+  char datebuf[FULLDATESIZE];
 
   RERR ("No revision on branch %s has%s%s%s%s%s%s.",
         revno,
@@ -243,7 +245,8 @@ cantfindbranch (char const *revno, char const date[datesize],
 static void
 absent (char const *revno, int field)
 {
-  RERR ("%s %s absent", ODDP (field) ? "revision" : "branch",
+  RERR ("%s %s absent",
+        ODDP (field) ? "revision" : "branch",
         TAKE (field, revno));
 }
 
@@ -329,7 +332,7 @@ genbranch (struct delta const *bpoint, char const *revno,
   register struct delta *d, *trail;
   register struct wlink const *bhead;
   int result;
-  char datebuf[datesize + zonelenmax];
+  char datebuf[FULLDATESIZE];
 
   field = 3;
   bhead = bpoint->branches;
@@ -432,7 +435,8 @@ genbranch (struct delta const *bpoint, char const *revno,
           if (state && STR_DIFF (state, trail->state))
             {
               RERR ("Revision %s has state %s.",
-                    trail->num, trail->state ? trail->state : "<empty>");
+                    trail->num,
+                    trail->state ? trail->state : "<empty>");
               return NULL;
             }
         }
@@ -456,7 +460,7 @@ genrevs (char const *revno, char const *date, char const *author,
   register struct delta *d;
   int result;
   char const *branchnum;
-  char datebuf[datesize + zonelenmax];
+  char datebuf[FULLDATESIZE];
 
   if (!(d = REPO (tip)))
     {
