@@ -1,6 +1,6 @@
 /* RCS utility functions
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -21,6 +21,8 @@
 */
 
 #include "base.h"
+#include "timespec.h"
+#include "stat-time.h"
 #include <stdarg.h>
 #include <string.h>
 #include <errno.h>
@@ -52,8 +54,15 @@
 #endif  /* defined USE_NORMAL_EXIT */
 
 static void
-exit_diff_trouble (void)
+exit_diff_trouble (char const *fmt, ...)
 {
+  va_list args;
+
+  /* Avoid ‘perror’ since it may misuse buffers.  */
+  va_start (args, fmt);
+  vcomplain (fmt, args);
+  va_end (args);
+  complain ("\n");
   _Exit (DIFF_TROUBLE);
 }
 
@@ -68,7 +77,7 @@ thank_you_and_goodnight (int const how)
     tempunlink ();
   _Exit ((how & TYAG_DIFF)
          ? DIFF_FAILURE
-         : EXIT_FAILURE);
+         : exit_failure);
 }
 
 void
@@ -82,11 +91,13 @@ gnurcs_init (struct program const *program)
   top = ZLLOC (1, struct top);
   unbuffer_standard_error ();
   top->program = program;
+  BE (pe) = WOE
+    ? "\\,v"
+    : ",v/";
   ISR_SCRATCH = isr_init (&BE (quiet));
   init_ephemstuff ();
   BE (maketimestuff) = ZLLOC (1, struct maketimestuff);
-  if (PROB (time (&BE (now))))
-    fatal_sys ("time");
+  gettime (&BE (now));
 
   /* Set ‘BE (mem_limit)’.  */
   {
@@ -128,6 +139,18 @@ redefined (int c)
   PWARN ("redefinition of -%c option", c);
 }
 
+void
+chk_set_rev (const char **rev, char *arg)
+{
+  if (! *arg)
+    return;
+
+  if (*rev)
+    PWARN ("redefinition of %s", ks_revno);
+
+  *rev = arg;
+}
+
 struct cbuf
 minus_p (char const *xrev, char const *rev)
 {
@@ -238,7 +261,9 @@ cgetenv (char const *name)
 {
   register char *p;
 
-  return (p = getenv (name)) ? str_save (p) : p;
+  return (p = getenv (name))
+    ? str_save (p)
+    : p;
 }
 
 void
@@ -265,7 +290,9 @@ movefd (int old, int new)
   if (PROB (old) || old == new)
     return old;
   new = fcntl (old, F_DUPFD, new);
-  return !PROB (close (old)) ? new : -1;
+  return !PROB (close (old))
+    ? new
+    : -1;
 }
 
 static int
@@ -325,20 +352,14 @@ runv (int infd, char const *outname, char const **args)
             && STDIN_FILENO != infd
             && STDIN_FILENO != (close (STDIN_FILENO),
                                 fcntl (infd, F_DUPFD, STDIN_FILENO)))
-          {
-            /* Avoid ‘perror’ since it may misuse buffers.  */
-            complain ("%s: I/O redirection failed\n", args[1]);
-            exit_diff_trouble ();
-          }
+          exit_diff_trouble ("%s: I/O redirection failed",
+                             args[1]);
 
         if (outname)
           if (PROB (fdreopen (STDOUT_FILENO, outname,
                               O_CREAT | O_TRUNC | O_WRONLY)))
-            {
-              /* Avoid ‘perror’ since it may misuse buffers.  */
-              complain ("%s: %s: cannot create\n", args[1], outname);
-              exit_diff_trouble ();
-            }
+            exit_diff_trouble ("%s: %s: cannot create",
+                               args[1], outname);
         EXECV (args[1], (char **) (args + 1));
         notfound = args[1];
 #ifdef RCS_SHELL
@@ -349,9 +370,7 @@ runv (int infd, char const *outname, char const **args)
           }
 #endif
 
-        /* Avoid ‘perror’ since it may misuse buffers.  */
-        complain ("%s: not found\n", notfound);
-        exit_diff_trouble ();
+        exit_diff_trouble ("%s: not found", notfound);
       }
     if (PROB (pid))
       fatal_sys ("fork");
@@ -530,4 +549,18 @@ getRCSINIT (int argc, char **argv, char ***newargv)
   return argc;
 }
 
+struct timespec
+unspecified_timespec (void)
+{
+  return make_timespec (TIME_UNSPECIFIED, ZERO_NANOSECONDS);
+}
+
+struct timespec
+file_mtime (bool enable, struct stat const *st)
+{
+  return enable
+    ? get_stat_mtime (st)
+    : unspecified_timespec ();
+}
+
 /* rcsutil.c ends here */
